@@ -12,7 +12,11 @@ public:
     register_param(hsync,"HSync","the hsync offset");
   }
   
-  virtual void update()
+  virtual void update(double time,
+                      uint32_t* out,
+		              const uint32_t* in,
+		              const uint32_t* in2,
+		              const uint32_t* in3)
   {
     unsigned int
       first_line=static_cast<unsigned int>(height*std::fmod(hsync,1.0));
@@ -29,5 +33,5 @@ private:
 frei0r::construct<nosync0r> plugin("nosync0r",
 				   "broken tv",
 				   "Martin Bayer",
-				   0,1);
+				   0,2);
 
